@@ -11,6 +11,7 @@ import os
 import hug
 import falcon
 import logging
+import json
 from typing import Union, List, Tuple
 from taccjm.TACCJobManager import TACCJobManager, TJMCommandError
 
@@ -157,7 +158,12 @@ def list_files(jm_id:str, path:str="."):
     """List files on system"""
     _check_init(jm_id)
 
-    return JM[jm_id].list_files(path=path)
+
+    logger.info(f'Getting files from {path}')
+    files = JM[jm_id].list_files(path=path)
+    _ = [f.pop('ls_str') for f in files]
+
+    return files
 
 
 @hug.get('/{jm_id}/files/peak')
@@ -265,7 +271,6 @@ def get_app(jm_id:str, app_id:str):
 def deploy_app(jm_id:str,
                local_app_dir:str='.',
                app_config_file:str="app.json",
-               proj_config_file:str="project.ini",
                overwrite:bool=False) -> dict:
     """Deploy App
 
@@ -279,7 +284,6 @@ def deploy_app(jm_id:str,
     return JM[jm_id].deploy_app(
                 local_app_dir=local_app_dir,
                 app_config_file=app_config_file,
-                proj_config_file=proj_config_file,
                 overwrite=overwrite)
 
 
@@ -305,9 +309,9 @@ def get_job(jm_id:str, job_id:str):
 
 @hug.post('/{jm_id}/jobs/deploy')
 def deploy_job(jm_id:str,
+               job_config:str=None,
                local_job_dir:str='.',
                job_config_file:str='job.json',
-               proj_config_file:str='project.ini',
                stage:bool=True,
                **kwargs):
     """ Deploy a job to TACC system. """
@@ -316,9 +320,9 @@ def deploy_job(jm_id:str,
     msg = f"{jm_id} - deploying job at path {local_job_dir}/{job_config_file}"
     logger.info(msg)
 
-    return JM[jm_id].deploy_job(local_job_dir=local_job_dir,
+    return JM[jm_id].deploy_job(job_config = None if job_config is None else json.loads(job_config),
+                                local_job_dir=local_job_dir,
                                 job_config_file=job_config_file,
-                                proj_config_file=proj_config_file,
                                 stage=stage,
                                 **kwargs)
 
@@ -379,7 +383,11 @@ def list_job_files(jm_id:str, job_id:str, path:str=''):
     """
     _check_init(jm_id)
 
-    return JM[jm_id].ls_job(job_id, path=path)
+    logger.info(f'Getting files from {path}')
+    files = JM[jm_id].ls_job(job_id, path=path)
+    _ = [f.pop('ls_str') for f in files]
+
+    return files
 
 
 @hug.get('/{jm_id}/jobs/{job_id}/files/download')
@@ -466,7 +474,7 @@ def deploy_script(jm_id:str, script_name:str, local_file:str=None):
 
 @hug.put('/{jm_id}/scripts/run')
 def run_script(jm_id:str, script_name:str,
-        job_id:str=None, args:[str]=[]):
+        job_id:str=None, args:hug.types.multiple=[]):
     """Run Script
 
     """
